/***************************************************************************
 *   Copyright (C) 2005 by Christoph Hormann  <chris_hormann@gmx.de>       *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. *
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef _povexe_H_
#define _povexe_H_

#include <qstring.h>

/**
	This class provides information about a POV-Ray executable.
	Most of it is determined from a test run of the program
	which is only done once and not before it is necessary.
*/
class POVExecutable : public QObject
{
	Q_OBJECT

	public:
		POVExecutable(const QString &name = "povray");
		~POVExecutable() {;}

		///	returns the full path to the executable
		inline QString path(void) const { return(exe_path); }
		///	returns the plain executable name (without path)
		inline QString name(void) const { return(id); }
		/**
			returns the version information produced by POV-Ray on every run
			if not already done a test run is started for that
		*/
		inline QString Version_Information(void) { TestRun(); return(version_info); }
		/**
			returns the compile information produced by POV-Ray on every run
			if not already done a test run is started for that
		 */
		inline QString Compile_Information(void) { TestRun(); return(compile_info); }
		/**
			returns the Library_Path settings configured (and printed by POV-Ray on every run)
			if not already done a test run is started for that
		 */
		inline QStringList Library_Paths(void) { TestRun(); return(LibPaths); }
		/**
			the version number as float extracted from the version string
			if not already done a test run is started for that
		 */
		inline float version(void) { TestRun(); return(pov_version); }
		/**
			the version number as string extracted from the version string
			if not already done a test run is started for that
		 */
		inline QString version_string(void) { TestRun(); return(pov_version_string); }

		/// returns if executable could be found
		bool exists(void);
		/// returns the full path of the ini file that configures this POV-Ray executable
		QString ini(void);

	protected slots:
		void slotGetStdError(KProcess*, char *s, int len);

	private:
		bool TestRun(void);
		QString id;
		QString exe_path;
		QString version_info;
		QString compile_info;
		QStringList LibPaths;
		float pov_version;
		QString pov_version_string;
		QString TmpDir;
		QString ErrorStream;
		bool info_generated;
		
};

#endif
